/* 
 * Copyright (c) 2012, Texas Instruments Incorporated
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * *  Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 *
 * *  Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * *  Neither the name of Texas Instruments Incorporated nor the names of
 *    its contributors may be used to endorse or promote products derived
 *    from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR
 * CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE,
 * EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * 
 */


/*
 *  ======== Settings.xdc ========
 *
 */

package ti.sdo.tiler;


/*!
 *  ======== Settings ========
 *  Global configuration settings for the ti.sdo.tiler package
 *
 */

metaonly module Settings
{

    // -------- Module Constants --------

    // -------- Module Types --------

    /*!
     *  Operating systems used for hosting the tiler manager
     *
     *  @value(OperSys_Linux) The tiler manager is running on Linux.
     *
     *  @value(OperSys_WinCE) The tiler manager is running on WindowsCE.
     *
     *  @value(OperSys_RTOS) The tiler manager is running on a real-time
     *  operating system which does not make a distinction between
     *  user and kernel modes.
     */
    enum OperSys {
        OperSys_Linux,
        OperSys_WinCE,
        OperSys_RTOS
    };

    /*!
     *  Specifies operating system on which the tiler manager is running
     *
     *  When configuring a program which is running on the same core
     *  as the tiler manager, set this config param to the host operating
     *  system. If the tiler manager is not part of the executable, then
     *  leave it undefined.
     *
     *  For example, if building an executable which is running on the same
     *  core as the tiler manager, (e.g. a local tiler client or the tiler
     *  daemon) then set this config param to the OS type. If building an
     *  executable which is making tiler calls to another core (e.g. a
     *  remote tiler client), then leave this config param undefined.
     */
    config OperSys tilerManagerOS;
}
/*
 *  @(#) ti.sdo.tiler; 1, 0, 0,1; 12-7-2012 15:04:26; /db/atree/library/trees/fc/fc-r16/src/ xlibrary

 */

